==> plainscape-6.x-1.0.tar.gz: plainscape/page.tpl.php <==
<?php
// $Id: page.tpl.php,v 1.3 2009/03/07 13:24:35 kong Exp $
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="<?php print $language->language ?>" lang="<?php print $language->language ?>" dir="<?php print $language->dir ?>">
  <head>
    <title><?php print $head_title ?></title>
    <?php print $head ?>
    <?php print $styles ?>
    <!--[if lt IE 7]>
    <link type="text/css" rel="stylesheet" media="all" href="<?php print drupal_get_path('theme', 'plainscape') ?>/css/ie.css" />
    <![endif]-->
    <?php print $scripts ?>
  </head>
  <body>
    <div id="wrapper" class="container_12">
      <div id="header" class="grid_12">
        <div id="header-left" class="grid_8 alpha">
          <?php if ($logo): ?>
            <a href="<?php print check_url($front_page) ?>" title="Go to Homepage"><?php print '<img src="'. check_url($logo) .'" alt="'. $site_title .'" id="logo" />' ?></a>
          <?php endif; ?>
          <?php if ($site_name): ?>
            <h1 id="site-name"><a href="<?php print check_url($front_page) ?>" title="Go to Homepage"><?php print $site_name ?></a></h1>
          <?php endif; ?>
          <?php if ($site_slogan): ?>
            <div id="site-slogan"><?php print $site_slogan ?></div>
          <?php endif; ?>
        </div><!-- #header-left -->
        <div id="header-right" class="grid_4 omega">
          <?php if ($search_box): ?>
            <div id="search-box"><?php print $search_box ?></div>
          <?php endif; ?>
        </div><!-- #header-right -->
        <div class="clear"></div>
      </div><!-- #header -->
      <div class="clear"></div>
      <div id="primary-nav" class="grid_12">
        <?php if (isset($primary_links)) : ?>
          <?php print theme('links', $primary_links) ?>
        <?php endif; ?>
      </div><!-- #primary-nav -->
      <div class="clear"></div>
      <div id="content-wrapper" class="grid_12">
        <div id="main" class="<?php print $main_classes ?>">
          <?php print $breadcrumb ?>
          <?php if ($content_top) : ?>
            <div id="content-top">
              <?php print $content_top ?>
            </div>
          <?php endif; ?>
          <?php if ($tabs) : ?>
            <ul class="tabs"><?php print $tabs ?></ul>
          <?php endif; ?>
          <?php if ($title && !$node): ?>
            <h2><?php print $title ?></h2>
          <?php endif; ?>
          <?php if ($show_messages && $messages) : ?>
            <?php print $messages ?>
          <?php endif; ?>
          <?php if ($help) : ?>
            <?php print $help ?>
          <?php endif; ?>
          <?php print $content ?>
          <?php if ($content_bottom) : ?>
            <div id="content-bottom">
              <?php print $content_bottom ?>
            </div>
          <?php endif; ?>
        </div>
        <?php if ($right): ?>
          <div id="sidebar" class="grid_4 omega">
            <?php print $right ?>
          </div>
        <?php endif; ?>
        <div class="clear"></div>
      </div><!-- #content-wrapper -->
      <div class="clear"></div>
      <div id="footer-top" class="grid_12">
        <?php print $footer_top ?>
      </div>
      <div id="footer" class="grid_12">
        <?php if ($footer_message): ?>
          <p><?php print $footer_message ?></p>
        <?php endif; ?>
        <p>Powered by <?php print l('Drupal', 'http://drupal.org') ?> and <?php print l('Plainscape', 'http://drupal.org/project/plainscape') ?> theme.<br />Ported to Drupal by <?php print l('kong', 'http://suksit.com') ?> under the <?php print l('GPL', 'http://www.opensource.org/licenses/gpl-license.php') ?> License. Valid <?php print l('XHTML', 'http://validator.w3.org/check?uri=referer') ?> | <?php print l('CSS', 'http://jigsaw.w3.org/css-validator/check/referer') ?></p>
        <?php print $footer ?>
      </div><!-- #footer -->
      <div class="clear"></div>
    </div><!-- #wrapper -->
    <?php print $closure ?>
  </body>
</html>

==> plainscape-6.x-1.2.tar.gz: plainscape/page.tpl.php <==
<?php
// $Id: page.tpl.php,v 1.5 2009/03/10 08:46:37 kong Exp $
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="<?php print $language->language ?>" lang="<?php print $language->language ?>" dir="<?php print $language->dir ?>">
  <head>
    <title><?php print $head_title ?></title>
    <?php print $head ?>
    <?php print $styles ?>
    <!--[if lt IE 7]>
    <link type="text/css" rel="stylesheet" media="all" href="<?php print drupal_get_path('theme', 'plainscape') ?>/css/ie.css" />
    <![endif]-->
    <?php print $scripts ?>
  </head>
  <body>
    <div id="wrapper" class="container_12">
      <div id="header" class="grid_12">
        <div id="header-left" class="grid_8 alpha">
          <?php if ($logo): ?>
            <a href="<?php print check_url($front_page) ?>" title="Go to Homepage"><?php print '<img src="'. check_url($logo) .'" alt="'. $site_name .'" id="logo" />' ?></a>
          <?php endif; ?>
          <?php if ($site_name): ?>
            <h1 id="site-name"><a href="<?php print check_url($front_page) ?>" title="Go to Homepage"><?php print $site_name ?></a></h1>
          <?php endif; ?>
          <?php if ($site_slogan): ?>
            <div id="site-slogan"><?php print $site_slogan ?></div>
          <?php endif; ?>
        </div><!-- #header-left -->
        <div id="header-right" class="grid_4 omega">
          <?php if ($search_box): ?>
            <div id="search-box"><?php print $search_box ?></div>
          <?php endif; ?>
        </div><!-- #header-right -->
        <div class="clear"></div>
      </div><!-- #header -->
      <div class="clear"></div>
      <div id="primary-nav" class="grid_12">
        <?php if (isset($primary_links)) : ?>
          <?php print theme('links', $primary_links) ?>
        <?php endif; ?>
      </div><!-- #primary-nav -->
      <div class="clear"></div>
      <div id="content-wrapper" class="grid_12">
        <div id="main" class="<?php print $main_classes ?>">
          <?php print $breadcrumb ?>
          <?php if ($content_top) : ?>
            <div id="content-top">
              <?php print $content_top ?>
            </div>
          <?php endif; ?>
          <?php if ($tabs) : ?>
            <ul class="tabs"><?php print $tabs ?></ul>
          <?php endif; ?>
          <?php if ($title && !$node): ?>
            <h2><?php print $title ?></h2>
          <?php endif; ?>
          <?php if ($show_messages && $messages) : ?>
            <?php print $messages ?>
          <?php endif; ?>
          <?php if ($help) : ?>
            <?php print $help ?>
          <?php endif; ?>
          <?php print $content ?>
          <?php if ($content_bottom) : ?>
            <div id="content-bottom">
              <?php print $content_bottom ?>
            </div>
          <?php endif; ?>
        </div>
        <?php if ($right): ?>
          <div id="sidebar" class="grid_4 omega">
            <?php print $right ?>
          </div>
        <?php endif; ?>
        <div class="clear"></div>
      </div><!-- #content-wrapper -->
      <div class="clear"></div>
      <div id="footer-top" class="grid_12">
        <?php print $footer_top ?>
      </div>
      <div id="footer" class="grid_12">
        <?php if ($footer_message): ?>
          <p><?php print $footer_message ?></p>
        <?php endif; ?>
        <p>Powered by <?php print $credits['drupal'] ?> and <?php print $credits['plainscape'] ?> theme.<br />Original design by <?php print $credits['original-author'] ?>. Ported to Drupal by <?php print $credits['author'] ?>.</p>
        <?php print $footer ?>
      </div><!-- #footer -->
      <div class="clear"></div>
    </div><!-- #wrapper -->
    <?php print $closure ?>
  </body>
</html>
